/*
** Copyright (C) 1993-2013 Mark B. Hanson (mbh@panix.com)
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2, or (at your option)
** any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// @(#)$Id: stamp.h 1344 2013-04-05 21:18:39Z mark $

#ifdef	XSC_STAMP_H

class Stamp;

#else	// XSC_STAMP_H
#define	XSC_STAMP_H

class Stamp {
private:
    long sec;
    long usec;

public:
    Stamp(void);
    ~Stamp(void);

    Stamp &operator=(const long);
    bool operator==(const Stamp &) const;
    bool operator!=(const Stamp &) const;
    Stamp &operator+=(const Stamp &);
    Stamp &operator-=(const Stamp &);
    bool operator>(const long);
    bool operator<(const long);

    long micros(void) const;
    void normalize(void);

    operator float() const;
    void set(const long, const long);
    long get_sec(void) const;
    long get_usec(void) const;
};

extern Stamp operator+(const Stamp &s1, const Stamp &s2);
extern Stamp operator-(const Stamp &s1, const Stamp &s2);


inline
Stamp::operator float() const
{
    return (float)(sec + (usec / 1000000.0));
} // Stamp::operator float


inline void
Stamp::set(const long s, const long u)
{
    sec = s;
    usec = u;
} // Stamp::set


inline long
Stamp::get_sec(void) const
{
    return sec;
} // Stamp::get_sec


inline long
Stamp::get_usec(void) const
{
    return usec;
} // Stamp::get_usec

#endif	// XSC_STAMP_H
